@@ -27,14 +27,16 @@
 //
 /////////////////////////////////////////////////////////
 GemCache :: GemCache(gemhead *parent)
-  : dirty(1), resendImage(0), m_parent(parent), m_magic(GEMCACHE_MAGIC)
+  : dirty(1), resendImage(0), vertexDirty(0),
+    m_parent(parent), m_magic(GEMCACHE_MAGIC)
 {
 }
 void GemCache :: reset(gemhead *parent)
 {
   dirty      =1;
   resendImage=0;
-  m_parent   =parent;
+  vertexDirty=0; 
+  m_parent   =parent; 
   m_magic    =GEMCACHE_MAGIC;
 }
 /////////////////////////////////////////////////////////
