@@ -15,12 +15,16 @@ LOG
 #ifndef INCLUDE_GEMEXPORTDEF_H_
 #define INCLUDE_GEMEXPORTDEF_H_
 
-#ifdef _WINDOWS
+#ifdef _MSC_VER
 
 /* turn of some warnings on vc-compilers */
-#pragma warning( disable : 4244 )
-#pragma warning( disable : 4305 )
-#pragma warning( disable : 4091 )
+# pragma warning( disable : 4244 )
+# pragma warning( disable : 4305 )
+# pragma warning( disable : 4091 )
+// f*cking M$DN and classes exporting STL members...
+# pragma warning( disable : 4251 )
+// "switch" without "case" (just "default")
+# pragma warning( disable : 4065 )
 
 // Windows requires explicit import and exporting of functions and classes.
 // While this is a pain to do sometimes, in large software development
