@@ -16,20 +16,14 @@
 
 #include "gemwin.h"
 
-// I hate Microsoft...I shouldn't have to do this!
-#ifdef _WINDOWS
-#include <windows.h>
-#endif
+#include "Base/GemGL.h"
  
 #ifdef __APPLE__
-#include <Carbon/carbon.h>
-#include <OpenGL/gl.h>
-#include "macosx_math.h"
-#else
-#include <GL/gl.h>
-#include <math.h>
+# include <Carbon/Carbon.h>
+# include <AvailabilityMacros.h>
 #endif // __APPLE__
 
+#include "Base/GemMath.h"
 #include "Base/GemMan.h"
 
 CPPEXTERN_NEW_WITH_ONE_ARG(gemwin, t_floatarg, A_DEFFLOAT)
@@ -58,10 +52,17 @@ static bool StillHaveGemWin(bool up) {
 /////////////////////////////////////////////////////////
 gemwin :: gemwin(t_floatarg framespersecond)
 {
-  if (framespersecond <= 0.)
-    framespersecond = 20.;
-  GemMan::frameRate((float)framespersecond);
-  if(!StillHaveGemWin(true))GemMan::resetState();
+  if(!StillHaveGemWin(true)) {
+    /* this is the only [gemwin] */
+    GemMan::resetState();
+    if (framespersecond <= 0.)
+      framespersecond = 20.;
+    GemMan::frameRate((float)framespersecond);
+  } else {
+    if(framespersecond>0.)
+      GemMan::frameRate((float)framespersecond);
+  }
+
   m_FrameRate       = outlet_new(this->x_obj, 0);
 }
 
@@ -83,10 +84,13 @@ void gemwin :: bangMess()
 {
   if ( GemMan::windowExists() )
     {
-      GemMan::swapBuffers();
+      if(1==GemMan::m_buffer)
+        GemMan::swapBuffers();
+      else /* double buffered mode */
+        GemMan::render(NULL);
     }
   else 
-    error("GEM: no window");
+    error("no window");
 }
 
 /////////////////////////////////////////////////////////
@@ -109,7 +113,7 @@ void gemwin :: renderMess()
 	if (GemMan::getRenderState())
 		GemMan::render(NULL);
 	else
-		error("GEM: not in render mode");
+		error("not in render mode");
 }
 /////////////////////////////////////////////////////////
 // titleMess
@@ -127,19 +131,22 @@ void gemwin :: createMess(t_symbol* s)
 {
   char* disp = NULL;
 
+  /* just in case a "pleaseDestroy" is still pending... */
+  GemMan::pleaseDestroy=false;
+ 
   if (s != &s_) 
     disp = s->s_name;
 
   if ( !GemMan::windowExists() )  {
     GemMan::createContext(disp);
     if ( !GemMan::createWindow(disp) )  {
-      error("GEM: gemwin: no window made");
+      error("no window made");
       return;
     }
     GemMan::swapBuffers();	
     GemMan::swapBuffers();	
   } else
-    error("GEM: gemwin: window already made");
+    error("window already made");
 }
 
 /////////////////////////////////////////////////////////
@@ -162,11 +169,11 @@ void gemwin :: bufferMess(int buf)
 void gemwin :: stereoMess(int mode)
 {
   if (mode<0){
-    error("GEM: stereo-mode must not be %d", mode);
+    error("stereo-mode must not be %d", mode);
     return;
   }
   if (mode>1) {
-    error("GEM: only stereo-modes 1/0 are allowed!!!");
+    error("only stereo-modes 1/0 are allowed!!!");
     return;
   }
 
@@ -182,6 +189,27 @@ void gemwin :: fullscreenMess(int on)
     GemMan::m_fullscreen = on;
 }
 
+/////////////////////////////////////////////////////////
+// menuBarMess		1 = show	-1 = hide, but autoshow
+//					0 = hide, but neverShow
+/////////////////////////////////////////////////////////
+void gemwin :: menuBarMess(int on)
+{
+  GemMan::m_menuBar = on;
+#ifdef __APPLE__
+  if (on == 0) {
+    SetSystemUIMode( kUIModeAllHidden, kUIOptionDisableAppleMenu |
+									   kUIOptionDisableProcessSwitch |
+									   kUIOptionDisableSessionTerminate |
+									   kUIOptionDisableForceQuit );
+  }else if (on > 0) {
+    SetSystemUIMode( kUIModeNormal, 0 );
+  }else if (on < 0) {
+    SetSystemUIMode( kUIModeAllHidden, kUIOptionAutoShowMenuBar );
+  }
+#endif
+}
+
 /////////////////////////////////////////////////////////
 // secondScreen
 //
@@ -198,12 +226,12 @@ void gemwin :: secondscreenMess(int on)
 void gemwin :: dimensionsMess(int width, int height)
 {
   if (width <= 0) {
-    error("GEM: gemwin: width must be greater than 0");
+    error("width must be greater than 0");
     return;
   }
     
   if (height <= 0 ) {
-    error ("GEM: gemwin: height must be greater than 0");
+    error ("height must be greater than 0");
     return;
   }
   GemMan::m_width = width;
@@ -222,20 +250,16 @@ void gemwin :: offsetMess(int x, int y)
 // colorMess
 //
 /////////////////////////////////////////////////////////
-void gemwin :: colorMess(float red, float green, float blue)
+void gemwin :: colorMess(float red, float green, float blue, float alpha)
 {
-#ifdef __APPLE__
-  if ( !GemMan::windowExists() )  {
-    post("GEM: gemwin: !windowExists");
-    return;
-  }
-#endif
-  glClearColor(red, green, blue, 0.);
   GemMan::m_clear_color[0] = red;
   GemMan::m_clear_color[1] = green;
   GemMan::m_clear_color[2] = blue;
+  GemMan::m_clear_color[3] = alpha;
+  if ( GemMan::windowExists() )  {
+    glClearColor(red, green, blue, alpha);
+  }
 }
-
 /////////////////////////////////////////////////////////
 // clearmaskMess
 //
@@ -249,22 +273,25 @@ void gemwin :: clearmaskMess(float bitmask)
 // ambientMess
 //
 /////////////////////////////////////////////////////////
-void gemwin :: ambientMess(float red, float green, float blue)
+void gemwin :: ambientMess(float red, float green, float blue, float alpha)
 {
   GemMan::m_mat_ambient[0] = red;
   GemMan::m_mat_ambient[1] = green;
   GemMan::m_mat_ambient[2] = blue;
+  GemMan::m_mat_ambient[3] = blue;
 }
 
 /////////////////////////////////////////////////////////
 // specularMess
 //
 /////////////////////////////////////////////////////////
-void gemwin :: specularMess(float red, float green, float blue)
+void gemwin :: specularMess(float red, float green, float blue, float alpha)
 {
   GemMan::m_mat_specular[0] = red;
   GemMan::m_mat_specular[1] = green;
   GemMan::m_mat_specular[2] = blue;
+  GemMan::m_mat_specular[2] = alpha;
+
 }
 
 /////////////////////////////////////////////////////////
@@ -308,12 +335,12 @@ void gemwin :: fogRangeMess(float start, float end)
 // fogColorMess
 //
 /////////////////////////////////////////////////////////
-void gemwin :: fogColorMess(float red, float green, float blue)
+void gemwin :: fogColorMess(float red, float green, float blue, float alpha)
 {
   GemMan::m_fogColor[0] = red;
   GemMan::m_fogColor[1] = green;
   GemMan::m_fogColor[2] = blue;
-  GemMan::m_fogColor[3] = 0.f;
+  GemMan::m_fogColor[3] = alpha;
 }
 
 /////////////////////////////////////////////////////////
@@ -341,7 +368,7 @@ void gemwin :: fogModeMess(int mode)
       break;
 
     default :
-      error("GEM : fogmode must be 0, 1, 2 or 3");
+      error("fogmode must be 0, 1, 2 or 3");
       break;
     }
 }
@@ -381,8 +408,6 @@ void gemwin :: blurMess(float setting)
 /////////////////////////////////////////////////////////
 void gemwin :: fpsMess()
 {
-//GemMan::m_fps = 0;
- // post("gemwin: fps %d",GemMan::fps);
     outlet_float(m_FrameRate,GemMan :: fps);
 }
 
@@ -424,6 +449,8 @@ void gemwin :: obj_setupCallback(t_class *classPtr)
 		  gensym("buffer"), A_FLOAT, A_NULL);
   class_addmethod(classPtr, (t_method)&gemwin::fullscreenMessCallback,
 		  gensym("fullscreen"), A_FLOAT, A_NULL);
+  class_addmethod(classPtr, (t_method)&gemwin::menuBarMessCallback,
+		  gensym("menubar"), A_FLOAT, A_NULL);
   class_addmethod(classPtr, (t_method)&gemwin::secondscreenMessCallback,
 		  gensym("secondscreen"), A_FLOAT, A_NULL);
   class_addmethod(classPtr, (t_method)&gemwin::dimensionsMessCallback,
@@ -431,7 +458,7 @@ void gemwin :: obj_setupCallback(t_class *classPtr)
   class_addmethod(classPtr, (t_method)&gemwin::offsetMessCallback,
 		  gensym("offset"), A_FLOAT, A_FLOAT, A_NULL);
   class_addmethod(classPtr, (t_method)&gemwin::colorMessCallback,
-		  gensym("color"), A_FLOAT, A_FLOAT, A_FLOAT, A_NULL);
+		  gensym("color"), A_GIMME, A_NULL);
   class_addmethod(classPtr, (t_method)&gemwin::clearmaskMessCallback,
 		  gensym("clearmask"), A_FLOAT, A_NULL);
   class_addmethod(classPtr, (t_method)&gemwin::perspectiveMessCallback,
@@ -441,14 +468,14 @@ void gemwin :: obj_setupCallback(t_class *classPtr)
   class_addmethod(classPtr, (t_method)&gemwin::fogMessCallback,
 		  gensym("fog"), A_GIMME, A_NULL);
   class_addmethod(classPtr, (t_method)&gemwin::fogColorMessCallback,
-		  gensym("fogcolor"), A_FLOAT, A_FLOAT, A_FLOAT, A_NULL);
+		  gensym("fogcolor"), A_GIMME, A_NULL);
   class_addmethod(classPtr, (t_method)&gemwin::fogModeMessCallback,
 		  gensym("fogmode"), A_FLOAT, A_NULL);
 
   class_addmethod(classPtr, (t_method)&gemwin::ambientMessCallback,
-		  gensym("ambient"), A_FLOAT, A_FLOAT, A_FLOAT, A_NULL);
+		  gensym("ambient"), A_GIMME, A_NULL);
   class_addmethod(classPtr, (t_method)&gemwin::specularMessCallback,
-		  gensym("specular"), A_FLOAT, A_FLOAT, A_FLOAT, A_NULL);
+		  gensym("specular"), A_GIMME, A_NULL);
   class_addmethod(classPtr, (t_method)&gemwin::shininessMessCallback,
 		  gensym("shininess"), A_FLOAT, A_NULL);
   class_addmethod(classPtr, (t_method)&gemwin::cursorMessCallback,
@@ -515,24 +542,37 @@ void gemwin :: fogMessCallback(void *data, t_symbol *, int argc, t_atom *argv)
       GetMyClass(data)->fogRangeMess(atom_getfloat(&argv[0]),atom_getfloat(&argv[1]));
       break;
     default:
-      error("GEM : fog message needs 1 or 2 arguments");
+      GetMyClass(data)->error("fog message needs 1 or 2 arguments");
     }
 }
-void gemwin :: fogColorMessCallback(void *data, t_float red, t_float green, t_float blue)
+void gemwin :: fogColorMessCallback(void *data, t_symbol*s,int argc, t_atom*argv)
 {
-  GetMyClass(data)->fogColorMess(red, green, blue);
+  float red, green, blue, alpha=1.f;
+  switch(argc){
+  case 4:
+    alpha=atom_getfloat(argv+3);
+  case 3:
+    red=  atom_getfloat(argv);
+    green=atom_getfloat(argv+1);
+    blue= atom_getfloat(argv+2);
+    GetMyClass(data)->fogColorMess((float)red, (float)green, (float)blue, (float)alpha);
+    break;
+  default:
+    GetMyClass(data)->error("\"fogcolor\" expects 3 or 4 values");
+  }
 }
 void gemwin :: fogModeMessCallback(void *data, t_float val)
 {
   GetMyClass(data)->fogModeMess((int)val);
 }
-void gemwin :: stereoMessCallback(void *, t_floatarg state)
+void gemwin :: stereoMessCallback(void *data, t_floatarg state)
 {
   int mode = (int)state;
-  if (mode<0 || mode>2){
-    error("GEM: possible stereo-modes are: 0, 1, 2");
+  if (mode<0 || mode>3){
+    GetMyClass(data)->error("possible stereo-modes are: 0, 1, 2, 3");
     return;
   }
+
   GemMan::m_stereo = mode;
 }
 void gemwin :: stereoSepMessCallback(void *, t_floatarg state)
@@ -563,11 +603,11 @@ void gemwin :: frameMessCallback(void *, t_floatarg rate)
 {
   GemMan::frameRate((float)rate);
 }
-void gemwin :: perspectiveMessCallback(void *, t_symbol *, int argc, t_atom *argv)
+void gemwin :: perspectiveMessCallback(void *data, t_symbol *, int argc, t_atom *argv)
 {
   if (argc != 6)
     {
-      error("GEM: perspec message needs 6 arguments");
+      GetMyClass(data)->error("perspec message needs 6 arguments");
       return;
     }
   GemMan::m_perspect[0] = atom_getfloat(&argv[0]);	// left
@@ -577,7 +617,7 @@ void gemwin :: perspectiveMessCallback(void *, t_symbol *, int argc, t_atom *arg
   GemMan::m_perspect[4] = atom_getfloat(&argv[4]);	// front
   GemMan::m_perspect[5] = atom_getfloat(&argv[5]);	// back
 }
-void gemwin :: viewMessCallback(void *, t_symbol *, int argc, t_atom *argv)
+void gemwin :: viewMessCallback(void *data, t_symbol *, int argc, t_atom *argv)
 {
   const float DEG2RAD = 0.01745329251994f;
   float azimuth = 0.f;
@@ -630,7 +670,7 @@ void gemwin :: viewMessCallback(void *, t_symbol *, int argc, t_atom *argv)
       break;
 
     default:
-      error("GEM: view message needs 3, 4, 5 or 9 arguments");
+      GetMyClass(data)->error("view message needs 3, 4, 5 or 9 arguments");
 
       // note :: LATER set the StereoView ...
     }
@@ -658,8 +698,8 @@ void gemwin :: createMessCallback(void *data, t_symbol* disp)
 }
 void gemwin :: createStereoMessCallback(void *data)
 {
-  error("GEM: 'createStereo' is deprecated and does not work any more");
-  error("GEM:   use 'stereo 1' + 'create' instead");
+  GetMyClass(data)->error("'createStereo' is deprecated and does not work any more");
+  GetMyClass(data)->error("use 'stereo 1' + 'create' instead");
 
 }
 void gemwin :: bufferMessCallback(void *data, t_floatarg buf)
@@ -670,6 +710,10 @@ void gemwin :: fullscreenMessCallback(void *data, t_floatarg on)
 {
   GetMyClass(data)->fullscreenMess((int)on);
 }
+void gemwin :: menuBarMessCallback(void *data, t_floatarg on)
+{
+  GetMyClass(data)->menuBarMess((int)on);
+}
 void gemwin :: secondscreenMessCallback(void *data, t_floatarg on)
 {
   GetMyClass(data)->secondscreenMess((int)on);
@@ -682,21 +726,57 @@ void gemwin :: offsetMessCallback(void *data, t_floatarg x, t_floatarg y)
 {
   GetMyClass(data)->offsetMess((int)x, (int)y);
 }
-void gemwin :: colorMessCallback(void *data, t_floatarg red, t_floatarg green, t_floatarg blue)
+void gemwin :: colorMessCallback(void *data, t_symbol*s, int argc, t_atom*argv)
 {
-  GetMyClass(data)->colorMess((float)red, (float)green, (float)blue);
+  float red, green, blue, alpha=0.f;
+  switch(argc){
+  case 4:
+    alpha=atom_getfloat(argv+3);
+  case 3:
+    red=  atom_getfloat(argv);
+    green=atom_getfloat(argv+1);
+    blue= atom_getfloat(argv+2);
+    GetMyClass(data)->colorMess((float)red, (float)green, (float)blue, (float)alpha);
+    break;
+  default:
+    GetMyClass(data)->error("\"color\" expects 3 or 4 values");
+  }
 }
 void gemwin :: clearmaskMessCallback(void *data, t_floatarg bitmask)
 {
   GetMyClass(data)->clearmaskMess((float)bitmask);
 }
-void gemwin :: ambientMessCallback(void *data, t_floatarg red, t_floatarg green, t_floatarg blue)
+void gemwin :: ambientMessCallback(void *data, t_symbol*s,int argc, t_atom*argv)
 {
-  GetMyClass(data)->ambientMess((float)red, (float)green, (float)blue);
+  float red, green, blue, alpha=1.f;
+  switch(argc){
+  case 4:
+    alpha=atom_getfloat(argv+3);
+  case 3:
+    red=  atom_getfloat(argv);
+    green=atom_getfloat(argv+1);
+    blue= atom_getfloat(argv+2);
+    GetMyClass(data)->ambientMess((float)red, (float)green, (float)blue, (float)alpha);
+    break;
+  default:
+    GetMyClass(data)->error("\"ambient\" expects 3 or 4 values");
+  }
 }
-void gemwin :: specularMessCallback(void *data, t_floatarg red, t_floatarg green, t_floatarg blue)
+void gemwin :: specularMessCallback(void *data, t_symbol*s,int argc, t_atom*argv)
 {
-  GetMyClass(data)->specularMess((float)red, (float)green, (float)blue);
+  float red, green, blue, alpha=1.f;
+  switch(argc){
+  case 4:
+    alpha=atom_getfloat(argv+3);
+  case 3:
+    red=  atom_getfloat(argv);
+    green=atom_getfloat(argv+1);
+    blue= atom_getfloat(argv+2);
+    GetMyClass(data)->specularMess((float)red, (float)green, (float)blue, (float)alpha);
+    break;
+  default:
+    GetMyClass(data)->error("\"specular\" expects 3 or 4 values");
+  }
 }
 void gemwin :: shininessMessCallback(void *data, t_floatarg val)
 {
