@@ -4,7 +4,9 @@ LOG
 
     A cone
 
-    Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) 1997-2000 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -13,7 +15,7 @@ LOG
 #ifndef INCLUDE_CONE_H_
 #define INCLUDE_CONE_H_
 
-#include "Base/GemGluObj.h"
+#include "cylinder.h"
 
 /*-----------------------------------------------------------------
 -------------------------------------------------------------------
@@ -28,15 +30,15 @@ KEYWORD
 DESCRIPTION
 
 -----------------------------------------------------------------*/
-class GEM_EXTERN cone : public GemGluObj
+class GEM_EXTERN cone : public cylinder
 {
-    CPPEXTERN_HEADER(cone, GemGluObj)
+    CPPEXTERN_HEADER(cone, cylinder)
 
     public:
 
 	    //////////
 	    // Constructor
-    	cone(t_floatarg size);
+  cone(t_floatarg size,t_floatarg slice);
     	
     protected:
     	
@@ -46,7 +48,7 @@ class GEM_EXTERN cone : public GemGluObj
 
     	//////////
     	// Do the rendering
-    	virtual void 	render(GemState *state);
+	virtual void setupParameters(void);
 };
 
 #endif	// for header file
