@@ -5,6 +5,8 @@ LOG
     Turn on alpha blending
     
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -35,7 +37,7 @@ class GEM_EXTERN alpha : public GemBase
 
         //////////
         // Constructor
-    	alpha();
+    	alpha(t_floatarg);
     	
     protected:
     	
@@ -59,6 +61,16 @@ class GEM_EXTERN alpha : public GemBase
     	// alpha test state
     	int	    	    m_alphaTest;
 
+	/////////
+	// depthtest
+	int                 m_depthtest;
+
+	//////////
+	// the blending function
+	GLenum              m_function;
+    	void	    	funMess(int fun);
+
+
     	//////////
     	// Alpha state changed
     	void	    	alphaMess(int alphaState);
@@ -66,14 +78,20 @@ class GEM_EXTERN alpha : public GemBase
      	//////////
     	// Alpha test changed
     	void	    	testMess(int alphaTest);
-    	
+
+     	//////////
+    	// Disable Depthtest
+    	void	    	depthtestMess(int i);
+
+    	t_inlet *m_inlet;
    private:
     	
     	//////////
     	// static member functions
     	static void 	alphaMessCallback(void *data, t_floatarg alpha);
         static void     testMessCallback(void *data, t_floatarg alphaTest);
-
+        static void     depthtestMessCallback(void*, t_floatarg);
+        static void     funMessCallback(void *data, t_floatarg alphaTest);
 };
 
 #endif	// for header file
