@@ -51,8 +51,7 @@ part_color :: ~part_color()
 /////////////////////////////////////////////////////////
 void part_color :: render(GemState *state)
 {
-	if (state->stereo == 0 ||
-		state->stereo == 1)
+	if (state->tickTime > 0.f)
 	{
 		pColorD(1.0f, PDLine, m_color1[0], m_color1[1], m_color1[2],
 							  m_color2[0], m_color2[1], m_color2[2]);
@@ -104,7 +103,7 @@ void part_color :: color1MessCallback(void *data, t_symbol*s, int argc, t_atom*a
 				 atom_getfloat(argv+2),
 				 (argc==4)?atom_getfloat(argv+3):1.0f);
   else {
-    error("GEM: part_color:: only 3 or 4 arguments are accepted as colours");
+    GetMyClass(data)->error("only 3 or 4 arguments are accepted as colours");
   }
 }
 void part_color :: color2MessCallback(void *data, t_symbol*s, int argc, t_atom*argv)
@@ -115,6 +114,6 @@ void part_color :: color2MessCallback(void *data, t_symbol*s, int argc, t_atom*a
 				 atom_getfloat(argv+2),
 				 (argc==4)?atom_getfloat(argv+3):1.0f);
   else {
-    error("GEM: part_color:: only 3 or 4 arguments are accepted as colours");
+    GetMyClass(data)->error("only 3 or 4 arguments are accepted as colours");
   }
 }
