@@ -4,7 +4,10 @@ LOG
 
     Set the alpha values of a pix
 
-    Copyright (c) 1997-1998 Mark Danks. mdanks@cybermed.ucsd.edu
+    Copyright (c) 1997-1998 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) 2002 James Tittle & Chris Clepper
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -46,7 +49,7 @@ class GEM_EXTERN pix_coloralpha : public GemPixObj
 
     	//////////
     	// Do the processing
-    	virtual void 	processImage(imageStruct &image);
+    	virtual void 	processRGBAImage(imageStruct &image);
 };
 
 #endif	// for header file
