@@ -35,13 +35,13 @@ pix_convolve :: pix_convolve(t_floatarg fRow, t_floatarg fCol)
 
     if (!row || !col )
     {
-    	error("GEM: pix_convolve: matrix must have some dimension");
+    	error("matrix must have some dimension");
     	return;
     }
     
     if (!(row % 2) || !(col % 2) )
     {
-    	error("GEM: pix_convolve: matrix must have odd dimensions");
+    	error("matrix must have odd dimensions");
     	return;
     }
     
@@ -67,8 +67,6 @@ pix_convolve :: pix_convolve(t_floatarg fRow, t_floatarg fCol)
 pix_convolve :: ~pix_convolve()
 {
     if (m_imatrix)delete [] m_imatrix;
-    post("done...");
-  
 }
 
 /////////////////////////////////////////////////////////
@@ -235,10 +233,14 @@ void pix_convolve :: processYUVImage(imageStruct &image)
     int initOffset = initY * xTimesc + initX * tempImg.csize;
     
  //   calculate3x3YUV(image,tempImg);
+ 
+//quick fix for Intel 3x3YUV problems
+#ifdef __BIG_ENDIAN__
     if (m_rows == 3 && m_cols == 3) {
       calculate3x3YUV(image,tempImg);
       return;
     }
+#endif
     if (m_chroma) {
     for (int y = initY; y < maxY; y++)   {
         int realY = y * xTimesc;
@@ -341,6 +343,7 @@ return;
 if (m_chroma){
   i = xsize;
  
+#ifdef i386
   register unsigned char val1 = 0;  
   register unsigned char val2 = src[i-xsize+1]; 
   register unsigned char val3 = src[i-xsize+3];
@@ -350,11 +353,25 @@ if (m_chroma){
   register unsigned char val7 = src[i+xsize-1];
   register unsigned char val8 = src[i+xsize+1];
   register unsigned char val9 = src[i+xsize+3];
-  
-length = size /2;
+#else 
+  register unsigned char val1 = 0;  
+  register unsigned char val2 = src[i-xsize+1]; 
+  register unsigned char val3 = src[i-xsize+3];
+  register unsigned char val4 = src[i-1];
+  register unsigned char val5 = src[i+1];
+  register unsigned char val6 = src[i+3];
+  register unsigned char val7 = src[i+xsize-1];
+  register unsigned char val8 = src[i+xsize+1];
+  register unsigned char val9 = src[i+xsize+3];
+#endif  
+
   //unroll this 2x to fill the registers? (matrix*y1*y2= 9*9*9 =27)
-i=xsize+1;
-    for (k=1;k<ysize;k++) {
+  //messed up looking on x86
+i=xsize+2;
+
+length = size /2;
+
+	  for (k=1;k<ysize;k++) {
         for (j=1;j<xsize;j++) {
   //load furthest value first...the rest should be in cache
     
@@ -694,7 +711,7 @@ void pix_convolve :: matrixMess(int argc, t_atom *argv)
 {
     if (argc != m_cols * m_rows)
     {
-    	error("GEM: pix_convolve: matrix size not correct");
+    	error("matrix size not correct");
     	return;
     }
 
