@@ -14,7 +14,9 @@
 
 #include "pix_halftone.h"
 
-#define NDEBUG
+#ifndef NDEBUG
+# define NDEBUG
+#endif
 #include <assert.h>
 
 CPPEXTERN_NEW(pix_halftone)
@@ -54,9 +56,6 @@ void pix_halftone :: processRGBAImage(imageStruct &image)
 {
     nWidth = image.xsize;
     nHeight = image.ysize;
-	int lumacnt =0;
-	int diffHi =0;
-	int diffLo = 0;
     
     pSource = (U32*)image.data;
 
@@ -78,7 +77,7 @@ void pix_halftone :: processRGBAImage(imageStruct &image)
 
     unsigned char* pDotFuncTableStart=&g_pDotFuncTable[0];
 
-    Pete_HalfTone_MakeDotFuncTable(pDotFuncTableStart,nCellSize,nStyle);
+    Pete_HalfTone_MakeDotFuncTable(pDotFuncTableStart,nCellSize,nStyle, 255.0f);
 
     unsigned char* pGreyScaleTableStart=&g_pGreyScaleTable[0];
 
@@ -229,10 +228,6 @@ void pix_halftone :: processYUVImage(imageStruct &image)
 {
     nWidth = image.xsize>>1;
     nHeight = image.ysize;
-	int luma1cnt=0;
-	int luma2cnt=0;
-	int diffHi=0, diffLo =0;
-	int diff2Hi=0, diff2Lo=0;
 	
     const unsigned char chroma = 128;
     pSource = (U32*)image.data;
@@ -258,7 +253,7 @@ void pix_halftone :: processYUVImage(imageStruct &image)
 
     unsigned char* pDotFuncTableStart=&g_pDotFuncTable[0];
 
-    Pete_HalfTone_MakeDotFuncTable(pDotFuncTableStart,nCellSize,nStyle);
+    Pete_HalfTone_MakeDotFuncTable(pDotFuncTableStart,nCellSize,nStyle, 235.0f);
 
     unsigned char* pGreyScaleTableStart=&g_pGreyScaleTable[0];
 
@@ -327,23 +322,10 @@ void pix_halftone :: processYUVImage(imageStruct &image)
 		U32 nLuminance=
 			GetImageAreaAverageLuma(
 				   nSampleLeftX,nSampleTopY,
-				   nCellSize>>1,nCellSize,
+				   nCellSize,nCellSize,
 				   pSource,nWidth,nHeight);
-				   //pSource,nWidth,nHeight)>>8;
-		//nLuminance/=256;
 		nLuminance+=220;
 		//nLuminance+=256;
-		//U32 nLuma1 = ((nLuminance & 0xffff0000)>>16)>>8;
-		//nLuma1/=256;
-		//nLuma1+=256;
-		
-		//U32 nLuma2 = ((nLuminance & 0x0000ffff)>>8);
-		//nLuma2/=256;
-		//nLuma2+=256;
-		//if (nLuma1 != 256)
-		//	luma1cnt += 1;
-		//if (nLuma2 != 256)
-		//	luma2cnt += 1;
 
 		int nCurrentYFP;
 		for (nCurrentYFP=CellBottom.Pos.nY; nCurrentYFP<=CellTop.Pos.nY; nCurrentYFP+=nFPMult) {
@@ -460,7 +442,7 @@ void pix_halftone :: processGrayImage(imageStruct &image)
 
     unsigned char* pDotFuncTableStart=&g_pDotFuncTable[0];
 
-    Pete_HalfTone_MakeDotFuncTable(pDotFuncTableStart,nCellSize,nStyle);
+    Pete_HalfTone_MakeDotFuncTable(pDotFuncTableStart,nCellSize,nStyle, 255.0f);
 
     unsigned char* pGreyScaleTableStart=&g_pGreyScaleTable[0];
 
@@ -599,25 +581,25 @@ int pix_halftone :: Init(int nWidth, int nHeight)
 void pix_halftone :: Pete_HalfTone_DeInit() {
   // do nothing
 }
-int pix_halftone :: RoundDotFunc(float X,float Y) {
+int pix_halftone :: RoundDotFunc(float X,float Y, float scale) {
   const float XSquared=(X*X);
   const float YSquared=(Y*Y);
   const float Result=(2.0f-(XSquared+YSquared))/2.0f;
 
-  return static_cast<int>(Result*255.0f);
+  return static_cast<int>(Result*scale);
 }
 
-int pix_halftone :: LineDotFunc(float X,float Y) {
+int pix_halftone :: LineDotFunc(float X,float Y, float scale) {
   const float Result=(1.0f-fabsf(Y));
-  return static_cast<int>(Result*255.0f);
+  return static_cast<int>(Result*scale);
 }
 
-int pix_halftone :: DiamondDotFunc(float X,float Y) {
+int pix_halftone :: DiamondDotFunc(float X,float Y, float scale) {
   const float Result=(2.0f-(fabsf(X)+fabsf(Y)))/2.0f;
-  return static_cast<int>(Result*255.0f);
+  return static_cast<int>(Result*scale);
 }
 
-int pix_halftone :: EuclideanDotFunc(float X,float Y) {
+int pix_halftone :: EuclideanDotFunc(float X,float Y, float scale) {
   const float AbsX=fabsf(X);
   const float AbsY=fabsf(Y);
   float Result;
@@ -631,10 +613,10 @@ int pix_halftone :: EuclideanDotFunc(float X,float Y) {
 
   Result/=2.0f;
 
-  return static_cast<int>(Result*255.0f);
+  return static_cast<int>(Result*scale);
 }
 
-int pix_halftone :: PSDiamondDotFunc(float X,float Y) {
+int pix_halftone :: PSDiamondDotFunc(float X,float Y, float scale) {
   const float AbsX=fabsf(X);
   const float AbsY=fabsf(Y);
 	
@@ -650,7 +632,7 @@ int pix_halftone :: PSDiamondDotFunc(float X,float Y) {
   }
 
   Result/=2.0f;
-  return static_cast<int>(Result*255.0f);
+  return static_cast<int>(Result*scale);
 }
 
 void pix_halftone :: Rotate(SPete_HalfTone_Point* pinPoint,SPete_HalfTone_Point* poutPoint,float Angle)
@@ -667,7 +649,8 @@ void pix_halftone :: Rotate(SPete_HalfTone_Point* pinPoint,SPete_HalfTone_Point*
     (SinFP*(pinPoint->nX>>nFPShift));
 }
 
-void pix_halftone :: Pete_HalfTone_MakeDotFuncTable(unsigned char* pDotFuncTableStart,int nCellSize,int nStyle) {
+void pix_halftone :: Pete_HalfTone_MakeDotFuncTable(unsigned char* pDotFuncTableStart,int nCellSize,int nStyle,
+													float scale) {
   const int nHalfCellSize=(nCellSize/2);
   unsigned char* pCurrentDotFunc=pDotFuncTableStart;
   int nCurrentY;
@@ -679,23 +662,23 @@ void pix_halftone :: Pete_HalfTone_MakeDotFuncTable(unsigned char* pDotFuncTable
       int nDotFuncResult;
       switch (nStyle) {
       case eRoundStyle: {
-	nDotFuncResult= RoundDotFunc(NormalX,NormalY);
+	nDotFuncResult= RoundDotFunc(NormalX,NormalY, scale);
       }break;
       case eLineStyle: {
-	nDotFuncResult=LineDotFunc(NormalX,NormalY);
+	nDotFuncResult=LineDotFunc(NormalX,NormalY, scale);
       }break;
       case eDiamondStyle: {
-	nDotFuncResult=DiamondDotFunc(NormalX,NormalY);
+	nDotFuncResult=DiamondDotFunc(NormalX,NormalY, scale);
       }break;
       case eEuclideanStyle: {
-	nDotFuncResult=EuclideanDotFunc(NormalX,NormalY);
+	nDotFuncResult=EuclideanDotFunc(NormalX,NormalY, scale);
       }break;
       case ePSDiamond: {
-	nDotFuncResult=PSDiamondDotFunc(NormalX,NormalY);
+	nDotFuncResult=PSDiamondDotFunc(NormalX,NormalY, scale);
       }break;
       default: {
 	assert(false);
-	nDotFuncResult=255;
+	nDotFuncResult=(int)scale;
       }break;
       }
       *pCurrentDotFunc=nDotFuncResult;
@@ -1155,10 +1138,8 @@ U32 pix_halftone :: GetImageAreaAverageLuma(int nLeftX,int nTopY,int nDeltaX,int
   U32* pSourceEnd=      pSourceStart+(nDeltaY*nImageWidth);
   U32* pCurrentSource=pSourceStart;
   
-  int nLuma1Total, nLuma2Total = 0;
   int nLumaTotal =0;
   int nLuma1, nLuma2 = 0;
-  int cnt =0;
 
   while (pCurrentSource<pSourceEnd) {
     U32* pSourceLineStart=pCurrentSource;
@@ -1252,11 +1233,11 @@ void pix_halftone :: sizeCallback(void *data, t_floatarg m_CellSize)
 {
   int size=(int)m_CellSize;
   if(size<1){
-    error("pix_halftone: size must not be < 0");
+    GetMyClass(data)->error("size must not be < 0");
     size=1;
   }
   if(size>nMaxCellSize){
-    error("pix_halftone: size must not be > %d", nMaxCellSize);
+    GetMyClass(data)->error("size must not be > %d", nMaxCellSize);
     size=nMaxCellSize;
   }
   GetMyClass(data)->m_CellSize=size;
@@ -1267,7 +1248,7 @@ void pix_halftone :: styleCallback(void *data, t_floatarg m_Style)
 {
   int style=(int)m_Style;
   if(style<0||style>4){
-    error("pix_halftone: style must be 0, 1, 2, 3 or 4");
+    GetMyClass(data)->error("style must be 0, 1, 2, 3 or 4");
     return;
   }
   GetMyClass(data)->m_Style=style;
