@@ -18,11 +18,6 @@ LOG
 #ifndef INCLUDE_PIX_RGBA_H_
 #define INCLUDE_PIX_RGBA_H_
 
-#ifdef __APPLE__
-#include <OpenGL/gl.h>
-#include <OpenGL/glext.h>
-#endif
-
 #include "Base/GemPixObj.h"
 
 /*-----------------------------------------------------------------
