@@ -5,6 +5,8 @@ LOG
     Snap a pix of the render buffer
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -44,7 +46,7 @@ class GEM_EXTERN pix_snap : public GemBase
 
         //////////
         // Constructor
-    	pix_snap();
+    	pix_snap(int argc, t_atom *argv);
     	
     protected:
     	
@@ -83,6 +85,7 @@ class GEM_EXTERN pix_snap : public GemBase
     	//////////
     	// The pixBlock with the current image
     	pixBlock    	m_pixBlock;
+	imageStruct     m_imageStruct;
     	
     	//////////
     	// The x position
