@@ -13,8 +13,7 @@
 #ifndef INCLUDE_GEM_GLLOGICOP_H_
 #define INCLUDE_GEM_GLLOGICOP_H_
 
-#include "Base/GemGLUtil.h"
-#include "Base/GemBase.h"
+#include "GemGLBase.h"
 
 /*
  CLASS
@@ -26,13 +25,13 @@
 	"glLogicOp( GLenum opcode)"
  */
 
-class GEM_EXTERN GEMglLogicOp : public GemBase
+class GEM_EXTERN GEMglLogicOp : public GemGLBase
 {
-	CPPEXTERN_HEADER(GEMglLogicOp, GemBase)
+	CPPEXTERN_HEADER(GEMglLogicOp, GemGLBase)
 
 	public:
 	  // Constructor
-	  GEMglLogicOp (t_float);	// CON
+  GEMglLogicOp (int, t_atom*); // CON
 
 	protected:
 	  // Destructor
@@ -42,7 +41,7 @@ class GEM_EXTERN GEMglLogicOp : public GemBase
 
 	// variables
 	  GLenum	opcode;		// VAR
-	  virtual void	opcodeMess(t_float);	// FUN
+	  virtual void	opcodeMess(t_atom);	// FUN
 
 
 	private:
@@ -51,6 +50,6 @@ class GEM_EXTERN GEMglLogicOp : public GemBase
 	  t_inlet *m_inlet[1];
 
 	// static member functions
-	  static void	 opcodeMessCallback (void*, t_floatarg);
+	  static void	 opcodeMessCallback (void*, t_symbol*,int,t_atom*);
 };
 #endif // for header file
