@@ -13,8 +13,7 @@
 #ifndef INCLUDE_GEM_GLPOLYGONMODE_H_
 #define INCLUDE_GEM_GLPOLYGONMODE_H_
 
-#include "Base/GemGLUtil.h"
-#include "Base/GemBase.h"
+#include "GemGLBase.h"
 
 /*
  CLASS
@@ -26,13 +25,13 @@
 	"glPolygonMode( GLenum face, GLenum mode)"
  */
 
-class GEM_EXTERN GEMglPolygonMode : public GemBase
+class GEM_EXTERN GEMglPolygonMode : public GemGLBase
 {
-	CPPEXTERN_HEADER(GEMglPolygonMode, GemBase)
+	CPPEXTERN_HEADER(GEMglPolygonMode, GemGLBase)
 
 	public:
 	  // Constructor
-	  GEMglPolygonMode (t_float, t_float);	// CON
+	  GEMglPolygonMode (int, t_atom*); // CON
 
 	protected:
 	  // Destructor
@@ -42,10 +41,10 @@ class GEM_EXTERN GEMglPolygonMode : public GemBase
 
 	// variables
 	  GLenum	face;		// VAR
-	  virtual void	faceMess(t_float);	// FUN
+	  virtual void	faceMess(t_atom);	// FUN
 
 	  GLenum	mode;		// VAR
-	  virtual void	modeMess(t_float);	// FUN
+	  virtual void	modeMess(t_atom);	// FUN
 
 
 	private:
@@ -54,7 +53,7 @@ class GEM_EXTERN GEMglPolygonMode : public GemBase
 	  t_inlet *m_inlet[2];
 
 	// static member functions
-	  static void	 faceMessCallback (void*, t_floatarg);
-	  static void	 modeMessCallback (void*, t_floatarg);
+	  static void	 faceMessCallback (void*,t_symbol*,int,t_atom*);
+	  static void	 modeMessCallback (void*,t_symbol*,int,t_atom*);
 };
 #endif // for header file
