@@ -13,8 +13,7 @@
 #ifndef INCLUDE_GEM_GLSELECTBUFFER_H_
 #define INCLUDE_GEM_GLSELECTBUFFER_H_
 
-#include "Base/GemGLUtil.h"
-#include "Base/GemBase.h"
+#include "GemGLBase.h"
 
 /*
  CLASS
@@ -26,9 +25,9 @@
 	"glSelectBuffer( GLsizei size, GLuint *buffer)"
  */
 
-class GEM_EXTERN GEMglSelectBuffer : public GemBase
+class GEM_EXTERN GEMglSelectBuffer : public GemGLBase
 {
-	CPPEXTERN_HEADER(GEMglSelectBuffer, GemBase)
+	CPPEXTERN_HEADER(GEMglSelectBuffer, GemGLBase)
 
 	public:
 	  // Constructor
@@ -37,8 +36,12 @@ class GEM_EXTERN GEMglSelectBuffer : public GemBase
 	protected:
 	  // Destructor
 	  virtual ~GEMglSelectBuffer ();
+          // check extensions
+          virtual bool isRunnable(void);
+
 	  // Do the rendering
 	  virtual void	render (GemState *state);
+	  virtual void	postrender (GemState *state);
 
 	// variables
 	  GLsizei	size;		// VAR
@@ -49,8 +52,9 @@ class GEM_EXTERN GEMglSelectBuffer : public GemBase
 
 	private:
 
-	// we need some inlets
+	  // we need some inlets
 	  t_inlet *m_inlet;
+	  t_outlet*m_bufout;
 
 	// static member functions
 	  static void	 sizeMessCallback (void*, t_floatarg);
